@@ -473,6 +473,14 @@ impl Parser {
             return Ok(Box::new(MessageValueExtractor::new()));
         }
 
+        if extractor_type == "ButtonIndexExtractor" {
+            if arguments.len() != 0 {
+                return Err(ParserError::WrongArgumentCount);
+            }
+
+            return Ok(Box::new(ButtonIndexExtractor::new()));
+        }
+
         Err(ParserError::UnknownExtractor(extractor_type))
     }
 
@@ -624,6 +632,33 @@ impl Parser {
             )));
         }
 
+        if filter_type == "U8IsEqualFilter" {
+            if arguments.len() != 1 {
+                return Err(ParserError::WrongArgumentCount);
+            }
+
+            return Ok(Box::new(U8IsEqualFilter::new(
+                arguments[0]
+                    .try_into()
+                    .map_err(|_| ParserError::DataError)?,
+            )));
+        }
+
+        if filter_type == "U8SetStateFilter" {
+            if arguments.len() != 2 {
+                return Err(ParserError::WrongArgumentCount);
+            }
+
+            return Ok(Box::new(U8SetStateFilter::new(
+                arguments[0]
+                    .try_into()
+                    .map_err(|_| ParserError::DataError)?,
+                arguments[1]
+                    .try_into()
+                    .map_err(|_| ParserError::DataError)?,
+            )));
+        }
+
         Err(ParserError::UnknownFilter(filter_type))
     }
 
@@ -734,6 +769,13 @@ impl Parser {
 
                 comma_next = false;
             } else {
+                if let Some(Token::Symbol(SymbolToken::CloseParenthesis)) =
+                    token_iterator.clone().next()
+                {
+                    token_iterator.next();
+                    break;
+                }
+
                 arguments.push(match_variable_or_value!(token_iterator, variable_map));
 
                 comma_next = true;
@@ -772,6 +814,7 @@ impl Parser {
             PROGRAMMER_SET_DEVICE_ADDRESS_EVENT_CODE,
             Variable::U16
         );
+        prepare_variable!(variable_map, MESSAGE_EVENT_CODE, Variable::U16);
     }
 }
 
